@@ -35,7 +35,7 @@ from .runners import (
     DefaultRunners,
 )
 from .site import (
-    Synchronize, GotoCurrentSiteQueue,
+    Synchronize, GotoCurrentSiteQueue, ShowSiteSyncErrors,
     WorkingSites, ExchangeSites,
     MinioFileUploader, MinioFileDownloader,
     RequestRevisions, MultiRequestRevisions,
@@ -56,7 +56,7 @@ class LoginPageWidget(CustomPageWidget):
         self.error_label = QtWidgets.QLabel(self)
         self.error_label.setText("")
 
-        self.lineedit_kitsu_id = QtWidgets.QLineEdit()
+        self.lineedit_kitsu_login = QtWidgets.QLineEdit()
         self.lineedit_kitsu_password = QtWidgets.QLineEdit()
         self.button_login = QtWidgets.QPushButton("Log in")
         self.button_login.setMinimumWidth(100)
@@ -71,7 +71,7 @@ class LoginPageWidget(CustomPageWidget):
 
         grid_layout = QtWidgets.QGridLayout()
         grid_layout.addWidget(self.label, 0, 0)
-        grid_layout.addWidget(self.lineedit_kitsu_id, 1, 0, 1, 2)
+        grid_layout.addWidget(self.lineedit_kitsu_login, 1, 0, 1, 2)
         grid_layout.addWidget(self.lineedit_kitsu_password, 2, 0, 1, 2)
         grid_layout.addWidget(self.error_label, 3, 0)
         grid_layout.addWidget(self.button_login, 3, 1)
@@ -80,17 +80,17 @@ class LoginPageWidget(CustomPageWidget):
         self.setLayout(grid_layout)
 
         self.button_login.clicked.connect(self.on_connection_validated)
-        self.lineedit_kitsu_id.returnPressed.connect(self.on_connection_validated)
+        self.lineedit_kitsu_login.returnPressed.connect(self.on_connection_validated)
         self.lineedit_kitsu_password.returnPressed.connect(self.on_connection_validated)
 
     def on_connection_validated(self):
-        kitsu_id = self.lineedit_kitsu_id.text()
+        kitsu_login = self.lineedit_kitsu_login.text()
         kitsu_password = self.lineedit_kitsu_password.text()
         logged_in = self.session.cmds.Flow.call(
             self.project_oid,
             "log_in",
             args={},
-            kwargs={"kitsu_id": kitsu_id, "kitsu_password": kitsu_password},
+            kwargs={"kitsu_login": kitsu_login, "kitsu_password": kitsu_password},
         )
 
         if logged_in:
@@ -287,11 +287,13 @@ class CleanZipFiles(flow.Action):
 
 
 class Synchronization(flow.Object):
-    ICON = ("icons.libreflow", "sync_arrow")
+
+    ICON = ("icons.libreflow", "sync")
     
     _project = flow.Parent()
     synchronize_files = flow.Child(SynchronizeFiles)
     show_jobs = flow.Child(GotoCurrentSiteQueue)
+    show_errors = flow.Child(ShowSiteSyncErrors)
     request_revisions = flow.Child(RequestRevisions)
     multi_request_revisions = flow.Child(MultiRequestRevisions)
 
@@ -634,27 +636,31 @@ class Project(flow.Object):
 
         return kitsu_api.host_is_valid()
 
-    def log_in(self, kitsu_id, kitsu_password):
+    def log_in(self, kitsu_login, kitsu_password):
         kitsu_api = self.kitsu_api()
 
         self.update_kitsu_host(self.admin.kitsu.server_url.get())
-        
-        if not kitsu_api.log_in(kitsu_id, kitsu_password):
+        kitsu_user_data = kitsu_api.log_in(kitsu_login, kitsu_password)
+
+        if kitsu_user_data is None:
             return 1
+        
+        kitsu_id = kitsu_user_data['user']['id']
 
         # Set current user
-        user_name = self.admin.users.get_user_name(kitsu_id)
-        
-        if not user_name:
+        # user_name = self.admin.users.get_user_name(kitsu_login)
+        user = self.admin.users.get_user(kitsu_id)
+
+        if user is None:
             # Create user profile if not registered
-            user = self.admin.users.add_user(kitsu_id)
+            user = self.admin.users.add_user(kitsu_id, kitsu_login)
 
             if not user:
                 return 2
 
-            user_name = user.name()
+            # user_name = user.name()
         
-        self.set_user(user_name)
+        self.set_user(user.name())
 
         # Create user folder at first login
         user_settings_folder = self.user_settings_folder()
