@@ -684,6 +684,67 @@ class Request(RequestAs):
         )
 
 
+class SyncErrorCounter(flow.DynamicMap):
+
+    _error_count = flow.Param([])
+
+    def refresh_error_count(self):
+        count = []
+        sites = self.root().project().get_working_sites()
+        site_names = sites.get_site_names(use_custom_order=True, active_only=True)
+
+        for name in site_names:
+            s = sites[name]
+            count.append((s.name(), s.oid(), len(s.get_jobs(status='ERROR'))))
+        
+        self._error_count.set(count)
+    
+    def columns(self):
+        return ['Site', 'Nb errors']
+
+    def rows(self):
+        count = self._error_count.get()
+        rows = []
+
+        for site_name, site_oid, nb_err in count:
+            style = {'icon': ('icons.libreflow', 'blank')}
+            oid = site_oid + '/queue'
+            
+            if nb_err > 0:
+                style['foreground-color'] = '#D5000D'
+                style['Nb errors_foreground-color'] = '#D5000D'
+            
+            rows.append((oid,
+                {
+                    'Site': site_name,
+                    'Nb errors': nb_err,
+                    'activate_oid': oid,
+                    '_style': style
+                }
+            ))
+        
+        return rows
+
+
+class ShowSiteSyncErrors(flow.Action):
+
+    error_counter = flow.Child(SyncErrorCounter).ui(
+        label='Errors',
+        expanded=True)
+
+    def get_buttons(self):
+        self.message.set('<h2>Synchronization errors</h2>')
+        return ['Refresh', 'Close']
+    
+    def run(self, button):
+        if button == 'Close':
+            return
+        
+        self.error_counter.refresh_error_count()
+        self.error_counter.touch()
+        return self.get_result(close=False)
+
+
 class ResetJobStatuses(flow.Action):
     _site = flow.Parent()
     status = flow.Param("WAITING", JobStatus)
@@ -981,6 +1042,8 @@ class ClearQueueAction(flow.Action):
 
 class RemoveEnvironmentVariableAction(flow.Action):
 
+    ICON = ('icons.gui', 'remove-symbol')
+
     _variable = flow.Parent().ui(hidden=True)
     _collection = flow.Parent(2).ui(hidden=True)
 
@@ -991,47 +1054,80 @@ class RemoveEnvironmentVariableAction(flow.Action):
         if button == 'Cancel':
             return
 
-        self._collection.touch()
+        collection = self._collection
         self._collection.remove(self._variable.name())
+        collection.touch()
 
 
 class EnvironmentVariable(flow.Object):
 
-    vars_collection = flow.Parent()
+    site = flow.Parent(2)
+    
     variable = flow.Param("")
-    value = flow.Param("")
-    remove_variable = flow.Child(RemoveEnvironmentVariableAction)
+    value_windows = flow.Param('')
+    value_linux   = flow.Param('')
+    value_darwin  = flow.Param('')
+    value = flow.Computed(cached=True)
+
+    remove_variable = flow.Child(RemoveEnvironmentVariableAction).ui(hidden=True)
+
+    def compute_child_value(self, child_value):
+        if child_value is self.value:
+            value = None
+            # Get the operative system
+            _os = platform.system()
+            if _os == "Linux":
+                value = self.value_linux.get()
+            elif _os == "Windows":
+                value = self.value_windows.get()
+            elif _os == "Darwin":
+                value = self.value_darwin.get()
+            else:
+                self.root().session().log_error('Unrecognized operative system')
+                value = None
+
+            self.value.set(value)
 
 
 class AddEnvironmentVariableAction(flow.Action):
 
     _vars_collection = flow.Parent().ui(hidden=True)
-    variable = flow.Param("")
-    value = flow.Param("")
+    variable = flow.SessionParam("")
+    value_windows = flow.SessionParam('')
+    value_linux   = flow.SessionParam('')
+    value_darwin  = flow.SessionParam('')
 
     def get_buttons(self):
         return ['Create', 'Cancel']
+    
+    def revert_params_to_defaults(self):
+        self.variable.revert_to_default()
+        self.value_windows.revert_to_default()
+        self.value_linux.revert_to_default()
+        self.value_darwin.revert_to_default()
 
     def run(self, button):
         var_name = self.variable.get().replace(' ', '_').upper()
+        value_windows = self.value_windows.get()
+        value_linux = self.value_linux.get()
+        value_darwin = self.value_darwin.get()
 
         if button == 'Cancel':
-            self.variable.set("")
-            self.value.set("")
+            self.revert_params_to_defaults()
             return
 
-        elif (len(var_name) == 0) or (len(self.value.get()) == 0) or (self._vars_collection.has_mapped_name(var_name)):
-            self.variable.set("")
-            self.value.set("")
+        elif (len(var_name) == 0) or (len(value_windows) == 0 and len(value_linux) == 0 and len(value_darwin) == 0) or (self._vars_collection.has_mapped_name(var_name)):
+            self.revert_params_to_defaults()
             return
 
         else:
             new_var = self._vars_collection.add(var_name)
             
             new_var.variable.set(var_name)
-            new_var.value.set(self.value.get())
-            self.variable.set("")
-            self.value.set("")
+            new_var.value_windows.set(value_windows)
+            new_var.value_linux.set(value_linux)
+            new_var.value_darwin.set(value_darwin)
+            self.revert_params_to_defaults()
             self._vars_collection.touch()
 
 
