@@ -219,7 +219,7 @@ class AddUserAction(flow.Action):
     _users = flow.Parent()
 
     id = flow.Param("").ui(label="ID")
-    kitsu_id = flow.Param("").ui(label="Kitsu ID")
+    kitsu_login = flow.Param("").ui(label="Kitsu login")
     status = flow.Param("User", UserStatus)
 
     def get_buttons(self):
@@ -230,7 +230,7 @@ class AddUserAction(flow.Action):
             return
 
         user = self._users.add(self.id.get())
-        user.kitsu_id.set(self.kitsu_id.get())
+        user.kitsu_id.set(self.kitsu_login.get())
         user.status.set(self.status.get())
 
         self._users.touch()
@@ -240,7 +240,8 @@ class User(flow.Object):
 
     ICON = ("icons.gui", "user")
 
-    kitsu_id = flow.Param("").ui(label="Kitsu ID")
+    kitsu_id = flow.Param("").ui(label="Kitsu login")
+    kitsu_uid = flow.Param("").ui(label="Kitsu ID")
     status = flow.Param("User", UserStatus).ui(editable=False)
 
     bookmarks = flow.Child(UserBookmarks)
@@ -257,20 +258,21 @@ class Users(flow.Map):
         return flow.injection.injectable(User)
 
     def columns(self):
-        return ["ID", "Kitsu ID", "Status"]
+        return ["ID", "Kitsu login", "Kitsu ID", "Status"]
 
     def is_admin(self, username):
         user = self.get_mapped(username)
         return user.status.get() == "Admin"
     
-    def add_user(self, kitsu_id, status="User"):
-        name = self.get_user_name(kitsu_id)
+    def add_user(self, kitsu_id, kitsu_login, status="User"):
+        name = self.get_user_name(kitsu_login)
 
         if name is None or self.has_mapped_name(name):
             return None
 
         user = self.add(name)
-        user.kitsu_id.set(kitsu_id)
+        user.kitsu_id.set(kitsu_login)
+        user.kitsu_uid.set(kitsu_id)
         user.status.set(status)
 
         return user
@@ -288,10 +290,18 @@ class Users(flow.Map):
         name = name.lower()
         
         return name
+    
+    def get_user(self, kitsu_id):
+        for u in self.mapped_items():
+            if u.kitsu_uid.get() == kitsu_id:
+                return u
+        
+        return None
 
     def _fill_row_cells(self, row, item):
         row["ID"] = item.name()
-        row["Kitsu ID"] = item.kitsu_id.get()
+        row["Kitsu login"] = item.kitsu_id.get()
+        row["Kitsu ID"] = item.kitsu_uid.get()
         row["Status"] = item.status.get()
 
 
