@@ -307,7 +307,7 @@ class Job(object):
         job.set_priority(priority)
         job.set_paused(paused)
         job._send_touch = True
-        actor.send_joblist_touched()
+        actor.send_job_created(jid)
 
         return job
 
@@ -692,6 +692,12 @@ class Jobs(Actor):
         self._job_touched_unsubscribe = self.session().channels_subscribe(
             job_touched=self._on_job_touched
         )
+        self._job_created_unsubscribe = self.session().channels_subscribe(
+            job_created=self._on_job_created
+        )
+        self._job_deleted_unsubscribe = self.session().channels_subscribe(
+            job_deleted=self._on_job_deleted
+        )
         self._joblist_touched_unsubscribe = self.session().channels_subscribe(
             joblist_touched=self._on_joblist_touched
         )
@@ -707,11 +713,25 @@ class Jobs(Actor):
         jid = message['data']
         self.session().dispatch_event('job_touched', jid=jid)
 
+    def _on_job_created(self, message):
+        jid = message['data']
+        self.session().dispatch_event('job_created', jid=jid)
+
+    def _on_job_deleted(self, message):
+        jid = message['data']
+        self.session().dispatch_event('job_deleted', jid=jid)
+
     def _on_joblist_touched(self, message):
         self.session().dispatch_event('joblist_touched')
 
     def send_job_touched(self, jid):
         self.session().publish(job_touched=jid)
+    
+    def send_job_created(self, jid):
+        self.session().publish(job_created=jid)
+
+    def send_job_deleted(self, jid):
+        self.session().publish(job_deleted=jid)
 
     def send_joblist_touched(self):
         self.session().publish(joblist_touched=self.jobids_set_name)
@@ -742,7 +762,7 @@ class Jobs(Actor):
         '''
         deleted = Job.delete(self, jid, forced)
         if deleted:
-            self.send_joblist_touched()
+            self.send_job_deleted(jid)
         return deleted
 
 
