@@ -28,7 +28,7 @@ class TaskFileItem(QtWidgets.QTreeWidgetItem):
     def on_checkstate_toggled(self, column):
         pass
     
-    def submit_playblast_job(self):
+    def submit_blender_playblast_job(self):
         f = self.file
         kwargs = dict(
             shot_name=f['shot'],
@@ -41,7 +41,7 @@ class TaskFileItem(QtWidgets.QTreeWidgetItem):
         if extension == 'blend':
             kwargs['use_simplify'] = (self.checkState(2) == QtCore.Qt.Checked)
         
-        return self._tree.parentWidget().submit_playblast_job(extension, **kwargs)
+        return self._tree.parentWidget().submit_blender_playblast_job(extension, **kwargs)
     
     def _update(self):
         f = self.file
@@ -558,7 +558,7 @@ class RenderSequencePlayblastsWidget(ProcessSequenceFilesWidget):
             args={}, kwargs={}
         )
     
-    def submit_playblast_job(self, file_extension, **kwargs):
+    def submit_blender_playblast_job(self, file_extension, **kwargs):
         kwargs['pool_name'] = self.combobox_pool.currentText()
         kwargs['priority'] = int(self.lineedit_priority.text())
         
@@ -588,7 +588,7 @@ class RenderSequencePlayblastsWidget(ProcessSequenceFilesWidget):
                     file_item = task_item.child(k)
                     
                     if file_item.checkState(0) == QtCore.Qt.Checked:
-                        file_item.submit_playblast_job()
+                        file_item.submit_blender_playblast_job()
         
         self._close_view()
     
